PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
utils.py File Reference

## Classes
class | pawpyseed.core.utils.PAWpyError
class | pawpyseed.core.utils.PAWpyWarning

## Namespaces
| pawpyseed.core.utils
| Miscellaneous utilities file for the Python portion of the code.

## Functions
def | pawpyseed.core.utils.check_spin (spin, nspin)
def | pawpyseed.core.utils.el (site)